pub struct UsedTokens {
pub input_tokens: f64,
pub input_cached_tokens: f64,
pub input_cache_write_tokens: f64,
pub output_tokens: f64,
pub output_reasoning_tokens: f64,
}Expand description
Amount of used tokens for a model call.
Fields
input_tokens: f64Total amount of input tokens used.
input_cached_tokens: f64Amount of cached tokens used.
This is a subset of Self::input_tokens.
input_cache_write_tokens: f64Amount of cache write tokens used.
This is a subset of Self::input_tokens.
output_tokens: f64Total amount of output tokens.
output_reasoning_tokens: f64Total amount of reasoning tokens.
This is a subset of Self::output_tokens.
Implementations
Sourceimpl UsedTokens
impl UsedTokens
Sourcepub fn from_span_data(data: &SpanData) -> Self
pub fn from_span_data(data: &SpanData) -> Self
Extracts UsedTokens from SpanData attributes.
Sourcepub fn raw_input_tokens(&self) -> f64
pub fn raw_input_tokens(&self) -> f64
Calculates the total amount of input tokens billed at the standard rate.
Both Self::input_cached_tokens and Self::input_cache_write_tokens are
subsets of Self::input_tokens and are billed separately at their own
(cached / cache-write) rates, so both are subtracted here to avoid charging
them twice.
Sourcepub fn raw_output_tokens(&self) -> f64
pub fn raw_output_tokens(&self) -> f64
Calculates the total amount of raw, non-reasoning output tokens.
Subtracts reasoning tokens from the total token count.